@@ -1,6 +1,6 @@
 /* gda-holder.c
  *
- * Copyright (C) 2003 - 2010 Vivien Malerba
+ * Copyright (C) 2003 - 2008 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -92,7 +92,6 @@ struct _GdaHolderPrivate
 	GType            g_type;
 	GdaHolder       *full_bind;     /* FULL bind to holder */
 	GdaHolder       *simple_bind;  /* SIMPLE bind to holder */
-	gulong           simple_bind_notify_signal_id;
 	
 	gboolean         invalid_forced;
 	gboolean         valid;
@@ -302,7 +301,6 @@ gda_holder_init (GdaHolder *holder)
 	holder->priv->g_type = G_TYPE_INVALID;
 	holder->priv->full_bind = NULL;
 	holder->priv->simple_bind = NULL;
-	holder->priv->simple_bind_notify_signal_id = 0;
 
 	holder->priv->invalid_forced = FALSE;
 	holder->priv->valid = TRUE;
@@ -317,8 +315,8 @@ gda_holder_init (GdaHolder *holder)
 }
 
 /**
- * gda_holder_new:
- * @type: (transfer none): the #GType requested
+ * gda_holder_new
+ * @type: the #GType requested
  *
  * Creates a new holder of type @type
  *
@@ -331,12 +329,12 @@ gda_holder_new (GType type)
 }
 
 /**
- * gda_holder_copy:
+ * gda_holder_copy
  * @orig: a #GdaHolder object to copy
  *
  * Copy constructor.
  * 
- * Note1: if @orig is set with a static value (see gda_holder_take_static_value()) 
+ * Note1: if @orig is set with a static value (see #gda_holder_take_static_value ()) 
  * its copy will have a fresh new allocated GValue, so that user should free it when done.
  *
  * Returns: a new #GdaHolder object
@@ -397,7 +395,7 @@ gda_holder_copy (GdaHolder *orig)
 }
 
 /**
- * gda_holder_new_inline:
+ * gda_holder_new_inline
  * @type: a valid GLib type
  * @id: the id of the holder to create, or %NULL
  * @...: value to set
@@ -571,10 +569,8 @@ gda_holder_set_property (GObject *object,
 			gda_holder_set_attribute_static (holder, GDA_ATTRIBUTE_DESCRIPTION, value);
 			break;
 		case PROP_GDA_TYPE:
-			if (holder->priv->g_type == GDA_TYPE_NULL) {
+			if (holder->priv->g_type == GDA_TYPE_NULL)
 				holder->priv->g_type = g_value_get_gtype (value);
-				g_object_notify ((GObject*) holder, "g-type");
-			}
 			else
 				g_warning (_("The 'g-type' property cannot be changed"));
 			break;
@@ -668,12 +664,12 @@ gda_holder_get_property (GObject *object,
 }
 
 /**
- * gda_holder_get_g_type:
+ * gda_holder_get_g_type
  * @holder: a #GdaHolder object
  * 
  * Get @holder's type
  *
- * Returns: (tranfer none): the data type
+ * Returns: the data type
  */
 GType
 gda_holder_get_g_type (GdaHolder *holder)
@@ -685,7 +681,7 @@ gda_holder_get_g_type (GdaHolder *holder)
 }
 
 /**
- * gda_holder_get_id:
+ * gda_holder_get_id
  * @holder: a #GdaHolder object
  *
  * Get the ID of @holder. The ID can be set using @holder's "id" property
@@ -703,7 +699,7 @@ gda_holder_get_id (GdaHolder *holder)
 
 
 /**
- * gda_holder_get_value:
+ * gda_holder_get_value
  * @holder: a #GdaHolder object
  *
  * Get the value held into the holder. If @holder is set to use its default value
@@ -738,14 +734,14 @@ gda_holder_get_value (GdaHolder *holder)
 }
 
 /**
- * gda_holder_get_value_str:
+ * gda_holder_get_value_str
  * @holder: a #GdaHolder object
- * @dh: (allow-none): a #GdaDataHandler to use, or %NULL
+ * @dh: a #GdaDataHandler to use, or %NULL
  *
  * Same functionality as gda_holder_get_value() except that it returns the value as a string
  * (the conversion is done using @dh if not %NULL, or the default data handler otherwise).
  *
- * Returns: (transfer full): the value, or %NULL
+ * Returns: the value, or %NULL
  */
 gchar *
 gda_holder_get_value_str (GdaHolder *holder, GdaDataHandler *dh)
@@ -771,9 +767,9 @@ gda_holder_get_value_str (GdaHolder *holder, GdaDataHandler *dh)
 static gboolean real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, GError **error);
 
 /**
- * gda_holder_set_value:
+ * gda_holder_set_value
  * @holder: a #GdaHolder object
- * @value: (allow-none): a value to set the holder to, or %NULL
+ * @value: a value to set the holder to, or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Sets the value within the holder. If @holder is an alias for another
@@ -806,7 +802,7 @@ gda_holder_set_value (GdaHolder *holder, const GValue *value, GError **error)
 }
 
 /**
- * gda_holder_set_value_str:
+ * gda_holder_set_value_str
  * @holder: a #GdaHolder object
  * @dh: a #GdaDataHandler to use, or %NULL
  * @value: a value to set the holder to, as a string
@@ -851,9 +847,9 @@ gda_holder_set_value_str (GdaHolder *holder, GdaDataHandler *dh, const gchar *va
 }
 
 /**
- * gda_holder_take_value:
+ * gda_holder_take_value
  * @holder: a #GdaHolder object
- * @value: (transfer full): a value to set the holder to
+ * @value: a value to set the holder to
  * @error: a place to store errors, or %NULL
  *
  * Sets the value within the holder. If @holder is an alias for another
@@ -1156,7 +1152,7 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
 }
 
 /**
- * gda_holder_take_static_value:
+ * gda_holder_take_static_value
  * @holder: a #GdaHolder object
  * @value: a const value to set the holder to
  * @value_changed: a boolean set with TRUE if the value changes, FALSE elsewhere.
@@ -1178,12 +1174,13 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
  * of which can prevent the change from happening) which can be connected to to have a greater control
  * of which values @holder can have, or implement some business rules.
  *
- * Returns: (transfer none): NULL if an error occurred or if the previous GValue was NULL itself. It returns
+ * Returns: NULL if an error occurred or if the previous GValue was NULL itself. It returns
  * the static GValue user set previously, so that he can free it.
+ *
  */
 GValue *
 gda_holder_take_static_value (GdaHolder *holder, const GValue *value, gboolean *value_changed,
-			      GError **error)
+							  GError **error)
 {
 	g_return_val_if_fail (GDA_IS_HOLDER (holder), FALSE);
 	g_return_val_if_fail (holder->priv, FALSE);
@@ -1192,7 +1189,7 @@ gda_holder_take_static_value (GdaHolder *holder, const GValue *value, gboolean *
 }
 
 /**
- * gda_holder_force_invalid:
+ * gda_holder_force_invalid
  * @holder: a #GdaHolder object
  *
  * Forces a holder to be invalid; to set it valid again, a new value must be assigned
@@ -1231,7 +1228,7 @@ gda_holder_force_invalid (GdaHolder *holder)
 
 
 /**
- * gda_holder_is_valid:
+ * gda_holder_is_valid
  * @holder: a #GdaHolder object
  *
  * Get the validity of @holder (that is, of the value held by @holder)
@@ -1258,7 +1255,7 @@ gda_holder_is_valid (GdaHolder *holder)
 }
 
 /**
- * gda_holder_set_value_to_default:
+ * gda_holder_set_value_to_default
  * @holder: a #GdaHolder object
  *
  * Set @holder's value to its default value.
@@ -1296,7 +1293,7 @@ gda_holder_set_value_to_default (GdaHolder *holder)
 }
 
 /**
- * gda_holder_value_is_default:
+ * gda_holder_value_is_default
  * @holder: a #GdaHolder object
  *
  * Tells if @holder's current value is the default one.
@@ -1314,7 +1311,7 @@ gda_holder_value_is_default (GdaHolder *holder)
 
 
 /**
- * gda_holder_get_default_value:
+ * gda_holder_get_default_value
  * @holder: a #GdaHolder object
  *
  * Get the default value held into the holder. WARNING: the default value does not need to be of 
@@ -1333,7 +1330,7 @@ gda_holder_get_default_value (GdaHolder *holder)
 
 
 /**
- * gda_holder_set_default_value:
+ * gda_holder_set_default_value
  * @holder: a #GdaHolder object
  * @value: a value to set the holder's default value, or %NULL
  *
@@ -1385,7 +1382,7 @@ gda_holder_set_default_value (GdaHolder *holder, const GValue *value)
 }
 
 /**
- * gda_holder_set_not_null:
+ * gda_holder_set_not_null
  * @holder: a #GdaHolder object
  * @not_null: TRUE if @holder should not accept %NULL values
  *
@@ -1401,7 +1398,7 @@ gda_holder_set_not_null (GdaHolder *holder, gboolean not_null)
 }
 
 /**
- * gda_holder_get_not_null:
+ * gda_holder_get_not_null
  * @holder: a #GdaHolder object
  *
  * Get wether the holder can be NULL or not
@@ -1418,7 +1415,7 @@ gda_holder_get_not_null (GdaHolder *holder)
 }
 
 /**
- * gda_holder_set_source_model:
+ * gda_holder_set_source_model
  * @holder: a #GdaHolder object
  * @model: a #GdaDataModel object or NULL
  * @col: the reference column in @model
@@ -1471,7 +1468,7 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
 
 
 /**
- * gda_holder_get_source_model:
+ * gda_holder_get_source_model
  * @holder: a #GdaHolder
  * @col: a place to store the column in the model sourcing the holder, or %NULL
  *
@@ -1482,7 +1479,7 @@ gda_holder_set_source_model (GdaHolder *holder, GdaDataModel *model,
  *
  * Otherwise, this method returns %NULL, and if @col is not %NULL, then it is set to 0.
  *
- * Returns: (transfer none): a pointer to a #GdaDataModel, or %NULL
+ * Returns: a pointer to a #GdaDataModel, or %NULL
  */
 GdaDataModel *
 gda_holder_get_source_model (GdaHolder *holder, gint *col)
@@ -1496,37 +1493,13 @@ gda_holder_get_source_model (GdaHolder *holder, gint *col)
 	return holder->priv->source_model;
 }
 
-/*
- * This callback is called when @holder->priv->simple_bind's GType was GDA_TYPE_NULL at the time
- * gda_holder_set_bind() was called, and it makes sure @holder's GType is the same as @holder->priv->simple_bind's
- */
-static void
-bind_to_notify_cb (GdaHolder *bind_to, GParamSpec *pspec, GdaHolder *holder)
-{
-	g_signal_handler_disconnect (holder->priv->simple_bind,
-				     holder->priv->simple_bind_notify_signal_id);
-	holder->priv->simple_bind_notify_signal_id = 0;
-	if (holder->priv->g_type == GDA_TYPE_NULL)
-		holder->priv->g_type = bind_to->priv->g_type;
-	else if (holder->priv->g_type != bind_to->priv->g_type) {
-		/* break holder's binding because type differ */
-		g_warning (_("Cannot bind holders if their type is not the same, "
-			     "breaking existing bind where '%s' was bound to '%s'"),
-			   gda_holder_get_id (holder), gda_holder_get_id (bind_to));
-		gda_holder_set_bind (holder, NULL, NULL);
-	}
-}
-
 /**
- * gda_holder_set_bind:
+ * gda_holder_set_bind
  * @holder: a #GdaHolder
  * @bind_to: a #GdaHolder or %NULL
  * @error: a place to store errors, or %NULL
  *
  * Sets @holder to change when @bind_to changes (and does not make @bind_to change when @holder changes).
- * For the operation to succeed, the GType of @holder and @bind_to must be the same, with the exception that
- * any of them can have a %GDA_TYPE_NULL type (in this situation, the GType of the two #GdaHolder objects
- * involved is set to match the other when any of them sets its type to something different than GDA_TYPE_NULL).
  *
  * If @bind_to is %NULL, then @holder will not be bound anymore.
  *
@@ -1550,10 +1523,7 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 	if (bind_to) {
 		g_return_val_if_fail (GDA_IS_HOLDER (bind_to), FALSE);
 		g_return_val_if_fail (bind_to->priv, FALSE);
-		
-		if ((holder->priv->g_type != GDA_TYPE_NULL) &&
-		    (bind_to->priv->g_type != GDA_TYPE_NULL) &&
-		    (holder->priv->g_type != bind_to->priv->g_type)) {
+		if (holder->priv->g_type != bind_to->priv->g_type) {
 			g_set_error (error, GDA_HOLDER_ERROR, GDA_HOLDER_VALUE_TYPE_ERROR,
 				     "%s", _("Cannot bind holders if their type is not the same"));
 			return FALSE;
@@ -1569,11 +1539,6 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 	if (holder->priv->simple_bind) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (holder->priv->simple_bind),
 						      G_CALLBACK (full_bind_changed_cb), holder);
-		if (holder->priv->simple_bind_notify_signal_id) {
-			g_signal_handler_disconnect (holder->priv->simple_bind,
-						     holder->priv->simple_bind_notify_signal_id);
-			holder->priv->simple_bind_notify_signal_id = 0;
-		}
 		g_object_unref (holder->priv->simple_bind);
 		holder->priv->simple_bind = NULL;
 	}
@@ -1585,13 +1550,6 @@ gda_holder_set_bind (GdaHolder *holder, GdaHolder *bind_to, GError **error)
 		g_signal_connect (G_OBJECT (holder->priv->simple_bind), "changed",
 				  G_CALLBACK (full_bind_changed_cb), holder);
 
-		if (bind_to->priv->g_type == GDA_TYPE_NULL)
-			holder->priv->simple_bind_notify_signal_id = g_signal_connect (bind_to, "notify::g-type",
-										       G_CALLBACK (bind_to_notify_cb),
-										       holder);
-		else if (holder->priv->g_type == GDA_TYPE_NULL)
-			g_object_set ((GObject*) holder, "g-type", bind_to->priv->g_type , NULL);
-
 		/* if bind_to has a different value than holder, then we set holder to the new value */
 		if (value1)
 			gda_value_free (value1);
@@ -1691,26 +1649,26 @@ full_bind_changed_cb (GdaHolder *alias_of, GdaHolder *holder)
 {
 	if (alias_of == holder->priv->simple_bind) {
 		const GValue *cvalue;
-		GError *lerror = NULL;
+		GError *error = NULL;
 		cvalue = gda_holder_get_value (alias_of);
-		if (! gda_holder_set_value (holder, cvalue, &lerror)) {
-			if (lerror && ((lerror->domain != GDA_HOLDER_ERROR) || (lerror->code != GDA_HOLDER_VALUE_NULL_ERROR)))
-				g_warning (_("Could not change GdaHolder to match value change in bound GdaHolder: %s"),
-					   lerror && lerror->message ? lerror->message : _("No detail"));
-			g_clear_error (&lerror);
+		if (! gda_holder_set_value (holder, cvalue, &error)) {
+			g_warning (_("Could not change GdaHolder to match value change in bound GdaHolder: %s"),
+				   error && error->message ? error->message : _("No detail"));
+			if (error)
+				g_error_free (error);
 		}
 	}
 	else
-		g_signal_emit (holder, gda_holder_signals [CHANGED], 0);
+		g_signal_emit (holder, gda_holder_signals[CHANGED], 0);
 }
 
 /**
- * gda_holder_get_bind:
+ * gda_holder_get_bind
  * @holder: a #GdaHolder
  *
  * Get the holder which makes @holder change its value when the holder's value is changed.
  *
- * Returns: (transfer none): the #GdaHolder or %NULL
+ * Returns: the #GdaHolder or %NULL
  */
 GdaHolder *
 gda_holder_get_bind (GdaHolder *holder)
@@ -1722,7 +1680,7 @@ gda_holder_get_bind (GdaHolder *holder)
 }
 
 /**
- * gda_holder_get_alphanum_id:
+ * gda_holder_get_alphanum_id
  * @holder: a #GdaHolder object
  *
  * Get an "encoded" version of @holder's name. The "encoding" consists in replacing non
@@ -1742,7 +1700,7 @@ gda_holder_get_alphanum_id (GdaHolder *holder)
 }
 
 /**
- * gda_holder_get_attribute:
+ * gda_holder_get_attribute
  * @holder: a #GdaHolder
  * @attribute: attribute name as a string
  *
@@ -1762,7 +1720,7 @@ gda_holder_get_attribute (GdaHolder *holder, const gchar *attribute)
 }
 
 /**
- * gda_holder_set_attribute:
+ * gda_holder_set_attribute
  * @holder: a #GdaHolder
  * @attribute: attribute name
  * @value: a #GValue, or %NULL
