@@ -57,10 +57,11 @@ gda_postgres_render_CREATE_DB (GdaServerProvider *provider, GdaConnection *cnc,
 		
 		dh = gda_server_provider_get_data_handler_g_type (provider, cnc, G_TYPE_STRING);
 		str = gda_data_handler_get_sql_from_value (dh, value);
-
-		g_string_append (string, " ENCODING ");
-		g_string_append (string, str);
-		g_free (str);
+		if (str) {
+			g_string_append (string, " ENCODING ");
+			g_string_append (string, str);
+			g_free (str);
+		}
 	}
 
 	value = gda_server_operation_get_value_at (op, "/DB_DEF_P/TABLESPACE");
