@@ -51,6 +51,7 @@ typedef struct {
 typedef struct {
 	GdaConnection      *cnc;
         PGconn             *pconn;
+	gboolean            pconn_is_busy;
         gint                ntypes;
         GdaPostgresTypeOid *type_data;
         GHashTable         *h_table;
@@ -58,7 +59,6 @@ typedef struct {
         /* Version of the backend to which we are connected */
         gchar              *version;
         gfloat              version_float;
-        gchar              *short_version;
 
         /* Internal data types not returned */
         gchar              *avoid_types;
