@@ -27,15 +27,13 @@
 #include "web-server.h"
 #include <libsoup/soup.h>
 #include "html-doc.h"
-#include <libgda/binreloc/gda-binreloc.h>
+#include "binreloc/sql-binreloc.h"
 
 /* Use the RSA reference implementation included in the RFC-1321, http://www.freesoft.org/CIE/RFC/1321/ */
 #include "global.h"
 #include "md5.h"
 
-#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
-#endif
 
 #define MAX_CHALLENGES 10
 #define MAX_AUTH_COOKIES 10
@@ -444,7 +442,7 @@ get_file (WebServer *server, SoupMessage *msg, const char *path, GError **error)
 	GMappedFile *mfile;
 	gchar *real_path;
 
-	real_path = gda_gbr_get_file_path (GDA_DATA_DIR, "libgda-4.0", "web", path, NULL);
+	real_path = sql_gbr_get_file_path (SQL_DATA_DIR, "libgda-4.0", "web", path, NULL);
 	if (!real_path)
 		return FALSE;
 
@@ -1390,10 +1388,16 @@ compute_object_content (HtmlDoc *hdoc, WebServer *webserver, const ConnectionSet
 	GValue *v0, *v1;
 	gboolean retval;
 
-	g_value_take_string ((v0 = gda_value_new (G_TYPE_STRING)),
-			     gda_sql_identifier_quote (schema, cs->cnc, NULL, FALSE, FALSE));
-	g_value_take_string ((v1 = gda_value_new (G_TYPE_STRING)),
-			     gda_sql_identifier_quote (name, cs->cnc, NULL, FALSE, FALSE));
+	if (gda_sql_identifier_needs_quotes (schema))
+		g_value_take_string ((v0 = gda_value_new (G_TYPE_STRING)),
+				     gda_sql_identifier_add_quotes (schema));
+	else
+		g_value_set_string ((v0 = gda_value_new (G_TYPE_STRING)), schema);
+	if (gda_sql_identifier_needs_quotes (name))
+		g_value_take_string ((v1 = gda_value_new (G_TYPE_STRING)),
+				     gda_sql_identifier_add_quotes (name));
+	else
+		g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), name);
 
 	mstruct = gda_meta_struct_new (gda_connection_get_meta_store (cs->cnc),
 				       GDA_META_STRUCT_FEATURE_ALL);
